# TODO: Remove NI imports once apps are updated to reference the "correct"
#  schemas since they are here just for backwards compatibility during app product transfer
from .schemas import (
    eloqua_cdo_record_data,
    eloqua_cdo_record_update_data,
    eloqua_contact_record_data,
    eloqua_retriever_timestamp)
